## Como mensurar um IPO ?

\citet{Ljungqvist_2004} argumenta que o IPO pode ser mensurado a partir da seguinte equação:

### Diferença percentual entre o preço da ação vendida no IPO e o preço negociado no mercado**

\citet{Ljungqvist_2004} diz que a mensuração é dada pela diferença percentual entre o preço de venda das ações no IPO para os investidores e o preço negociado posteriormente no mercado (preço de fechamento da ação de acordo com o período analisado), sendo assim têm-se a equação 1:


\begin{equation} Ri,t = \frac{Pi,t}{Pi,ipo} - 1 \end{equation} 


Onde:

_Ri,t_ = retorno da ação no _t-ésimo_ dia de negociação

_Pi,t_ = cotação de fechamento da ação _i_ no seu _t-ésimo_ dia de negociação

_Pi,ipo_ = cotação da ação _i_ estabelecida para a oferta inicial

\citet{Ljungqvist_2004} também afirma que em mercado bem-desenvolvidos e que tenham ausência de restrições sobre o quanto um preço pode flutuar dia-a-dia, a extensão da subprecificação ocorre de maneira rápida, e pode ser analisada considerando a cotação do ação ao final do dia, que é a referência utilzada por grande parte dos estudos.

Já quando se analisa mercados menos desenvolvidos e que possuam "limites de volatilidade diária" que restrinjam as flutuações do preço das ações, \citet{Ljungqvist_2004} o preço considerado deve tomar um pouco mais tempo para ser determinado, de modo que a oferta e a demanda se equilibrem. Por exemplo, a Bolsa de Atenas possui um limite de flutuação de 8% (para mais ou para menos), então quando se foi analisar diversos IPO subprecificados, o retorno do primeiro dia ficou em 8% por conta das regulações, por tanto, nestes casos é mais importando que se análise um intervalo de tempo maior. 

Além deste, existem outro métodos propostos para mensuração do IPO, como por exemplo:
 
### Retorno ajustado ao mercado (_Market Adjusted Return_, sigla: AR ou MAR)

É o método mais utilizado na literatura para a mensuração dos resultados do IPOs em curto e longo prazo, como por exemplo nos estudos de \citet{Goergen_2007}, \citet{Jelic_2001} onde a fórmula é apresentada na equação 2.

\begin{equation} ARi,t = Ri,t - Rm,t \end{equation}   

Onde: 
    
_ARi,t_ = retorno ajustado ao mercado da ação _i_ no _t-ésimo_ dia de negociação

_Ri,t_ = retorno da ação _i_ no _t-ésimo_ dia de negociação

_Rm,t_ = retorno do benchmark de mercado para o _t-ésimo_ dia após a data do IPO da empresa _i_ 

### Retorno anormal acumulado ajustado ao mercado (_Market adjusted cumulative abnormal returns_, sigla: MACAR)

Método utilizado nos estudos por \citet{Goergen_2007} e também por \citet{Espenlaub_2000}, o MACAR é apresentado pela equação 3 e também é utilizado para mensurar resultados de longo prazo. 

\[ MACARi,q,s=\sum_{k=q+1}^{s+1}\frac{1}{s} \sum_{t=q}^{s}{ARi,t} \]

Onde:
    
_MACARi,q,s_ = retorno anormal acumulado ajustado ao mercado _i_ para o intervalo de negociações entre o _q-ésimo_ e o _s-ésimo_ dia

_ARi,t_ = retorno anormal da empresa _i_ no mês _t_

_S_ = número de empresas na amostra

### Retorno anormal ajustado ao mercado (_Market Adjusted Abnormal Return_, sigla: MAAR)

\citet{RITTER_1991} propôs um indicador de IPO denominado WR (wealth relatives), que tinha como objetivo calcular o retorno do IPO a partir da relação percentual entre o retorno do IPO e um benchmark. Em seguida, \citet{Goergen_2007} e outros autores utilizaram o MAAR, que é um indicador similar ao Wr e que mensura os retornos de curto e longo prazo, representado pela equação 4.

\begin{equation} MAARi,t = \frac{Ri,t + 1}{Rm,t +1} -1 \end{equation}   

Onde: 
    
_MAARi,t_ = retorno anormal ajustado ao mercado da ação _i_ no _t-ésimo_ dia de negociação

_Ri,t_ = retorno da ação _i_ no _t-ésimo_ dia de negociação

_Rm,t_ = retorno do benchmark de mercado para o _t-ésimo_ dia após a data do IPO da empresa _i_

### Média mensal do retorno anormal ajustado ao mercado (_Average Monthly Market Adjusted Return_, sigla: MMAR)

\citet{Chi_2005} e \citet{Procianoy} utilizaram em seu trabalho o MMAR, que é a média aritmética do MAAR (calculado mensalmente) e segue a fórmula dada pele equação 5.

\begin{equation} MAARi,t = \frac{\frac{Ri,t + 1}{Rm,t +1}-1}n \end{equation}   

Onde:
    
_MMARi,t_ = média mensal do retorno anormal ajustado ao mercado da ação _i_ no _t-ésimo_ mês de negociação

_Ri,t_ = retorno da ação _i_ no _t-ésimo_ mês de negociação

_Rm,t_ = retorno do benchmark de mercado para _t-ésimo_ mês após a data do IPO da empresa _i_

_n_ = número de meses até o período _t_

### _Market adjusted Buy and Hold Returns_ (BHR, BHAR ou MABHR)

É o mais utilizado para mensuração de IPOs no longo prazo. Diferentemente dos outros métodos, o BHAR é calculado a partir do preço de fechamento da cotação do primeiro dia da ação, e não pelo valor de lançamento dela no IPO. \citet{Ritter_2002}, \citet{G_nther_2006}, \citet{Chi_2005}, \citet{Ljungqvist_2004} mensuraram seus estudos no longo prazo utilizando a equação 6:

\[ BHARi,t = \prod_{t=1}^t(1+Ri,t) - \prod_{t=1}^t(1 + Rm,t) \]

Onde:
    
_BHARi,t_ = retorno ajustado ao mercado "buy and hold" da ação _i_ no _t-ésimo_ dia de negociação

_Ri,t_= retorna da ação _i_ no _t-ésimo_ mês de negociação

_Rm,t_= retorno do benchmark de mercado para o _t-ésimo_ mês após a data do IPO da empresa _i_ 