### Modelo de Retorno Ajustado ao Preço Médio Ponderado Total (ARpmpt)

A grande maioria dos modelos aplicados são restritos a apenas um dia de mensuração, o dia do lançamento da ação. Portanto, uma mensuração fidedigna deve considerar não apenas o preço do primeiro dia de negociação, e sim deve-se tomar como referência a data na qual a quantidade de ações negociadas no mercado (soma de todas as negociações diárias) seja igual as emitidas no IPO.

O objetivo da escolha dessa variável é relacionar o volume arrecadado pela empresa no IPO ao volume total de dinheiro negociado pelos investidores no mercado secundário, pois, dessa forma considera-se a "intenção" do mercado em negociar determinada ação. E então, ao tomar como referencial a quantidade de ações emitidas no IPO, é possível comparar o volume monetário arrecadado pela empresa e o volume de negócios que o mercado estaria disposto a fazer envolvendo aquela ação, mostrando assim uma informação que considere de modo mais realista as demandas por determinado papel.

Por tanto, como primeiro passo, determina-se o intervalo de tempo que será utilizado para a mensuração. Esse intervalo de tempo varia de caso a caso, porém, deve ser sempre iniciado no dia do IPO (primeiro dia de negociações da ação), e é limitado até o dia que o volume de negociações da ação no mercado secundário seja igual ao número de ações lançadas no IPO. Por tanto, a variável tempo é determinada a partir da igualdade entre o número de ações lançadas no IPO e o número de ações negociadas no mercado secundário.

Por exemplo, se uma empresa lança 10.000 ações em seu IPO. E no primeiro dia, 5.000 dessas ações foram negociadas, no segundo dia 3.000 foram negociadas e no terceiro dia 2.000 foram negociadas. A variável tempo para efeito do nosso cálculo seria 3, pois, foram necessários 3 dias para que o número de ações negociadas no mercado, sejam iguais ao número de ações lançadas no IPO.

Outra observação importante a respeito do tempo neste método é que ele busca refletir a vontade dos investidores em realizar negociações (compra e venda) daquele determinado papel, ignorando assim a origem da negociação, ou seja, não importa se quem estava vendendo as ações é a própria companhia ou alguém que comprou as ações da companhia e as guardava para serem comercializadas no mercado secundário.

Para facilitar o entendimento, tomemos o exemplo anterior novamente. Supondo que as 5.000 ações negociadas no primeiro dia, sejam renegociadas no mercado secundário no segundo dia, gerando mais 5.000 negociações entre elas, enquanto isso, as outras 5.000 ações permanecem nas mãos da companhia. Por mais, que todas as ações lançadas no IPO não sejam negociadas, tivemos 10.000 negociações envolvendo aquele papel, respeitando e demonstrando a intenção do mercado em negociar aquela ação.  Ou seja, por mais que os investidores não saibam a origem do papel que estão adquirindo (mercado secundário ou primeiro lançamento da companhia), o intervalo de tempo leva em consideração a reação do mercado em relação a determinado papel.

Após determinar esse intervalo, soma-se todo o volume monetário de negócios envolvendo essas ações até a data limite estipulada, e divide-se por tanto pela quantidade total de ações negociadas (que deve ser igual ou maior do que as emitidas no IPO). Por tanto temos o preço médio ponderado dessa ação em função do tempo _t_, e como esse preço médio representa o volume, teremos um resultado muito mais fidedigno para a empresa emissora das ações, de acordo com as equações abaixo:

\[QT_i \approx Q_i,ipo\]

\[QT_i = \sum_{t=1}^{k}Q_i,_t\]

\[TOVT_i = \sum_{t=1}^{k}TOV_i,_t\]

\[PMPT_i = \frac{TOVT_i}{QT_i}\]

\[R^{\prime\prime}_i,_k = \frac{PMPT_i}{P_i,_ipo} - 1\]

\[ R_m,_k = \prod_{t=1}^{k}R_m,_t\]

Onde: 

_QTi_ = quantidade total de ações _i_ negociadas até o dia que seja igual ao número de ações emitidas no IPO;
_Qi,ipo_ = quantidade de ações _i_ emitidas no IPO;
_k_ = número de dias até que a quantidade negociada da ação _i_ no mercado secundário se iguale à quantidade de ações lançadas no IPO;
_Qi,t_ = quantidade de ações _i_ negociadas no dia _t_;
_TOVTi_ = soma do volume monetário das negociações da ação _i_ nos _k_ dias;
_PMPTi_ = preço médio ponderado total das ações _i_ realizadas nos _k_ dias;
_R''i,k_ = é o retorno acumulado da ação _i_ no _t-ésimo_ dia de negociação, em relação ao preço médio ponderado total (PMPT);
_Pi,ipo_ = cotação da ação _i_ estabelecida para a venda na primeira oferta;
_Rm,t_ = retorno do índice de mercado no _t-ésimo_ dia de negociação da ação _i_;
_Rm,k_ = retorno do benchmark analisado, acumulado nos k dias;

Por tanto, o _ARpmpti_ será:

\[ AR_pmpt,_i = R^{\prime\prime}_i,_k - R_m,_k\]

Onde:

_ARpmpti_ = retorno ajustado  ao PMPT da ação _i_ no _k-ésimo_ dia de negociação;
_R''i,k_ = retorno acumulado da ação _i_ no _k-ésimo_ dia de negociação, em relação ao preço médio ponderado total (PMPT);
_Rm,k_ = retorno do benchmark de mercado, acumulado do dia de abertura da ação _i_ até o _k-ésimo_ dia de negociação;

Em resumo, o PMPT é a média ponderada dos preços de todos os valores negociados da ação até o dia em que a quantidade de ações negociadas no mercado seja igual ao número de ações lançadas no IPO. Já o _ARpmpt_ utiliza o PMPT como base para calcular o retorno (_R''i,k), refletindo assim a disposição dos investidores em negociar determinada ação, e consequentemente apresentando a informação de quanto dinheiro a empresa "deixou na mesa"  ou se arrecadou mais do que o mercado deveria ter pago, gerando ônus para os investidores.
